from distutils.core import setup

setup(
    name = "nesterx1",
    version = '1.1.2',
    py_modules = ['nester'],
    author = 'electricface',
    author_email = 'songwentai@linuxdeepin.com',
    url = "https://www.example.com",
    description = 'A simple printer of nested lists',
)
